////////////////////////////////////////////////////////////////////////////////
//
//  THIS CODE IS NOT APPROVED FOR USE IN/ON ANY OTHER UI ELEMENT OR PRODUCT COMPONENT.
//  Copyright (c) 2007 David E. Craig.  All rights reserved.
//
////////////////////////////////////////////////////////////////////////////////
/*
DESCRIPTION
===========
The CORE.JS file contains all the functions that are core
to the whole gadget. Different features of the gadget will
use these same et of functions again and again.

NOTE: External dependencies should be avoided if at all 
      possible.
*/

// GLOBAL CONSTANTS
var APP_NAME = "The Magic Folder";
var APP_NAME_INSTALL = "TheMagicFolder.gadget";
var NAMESPACE = "Microsoft";
var SIDEBAR = "windows sidebar";
var WARNING_COLOR = "Red";
var UPDATE_URL = "http://www.kryl.com/bin/TheMagicFolder.php";
var VERSION = "2.0.0.1";
var FIRST_RUN = "firstRun2001";
var DL_URL = "http://gallery.live.com/liveItemDetail.aspx?li=0ed6a06a-6782-41a7-b68c-2753fad412a5";

// GLOBAL VARS
var sections = new Array();
var extensions = new Array();
var paths = new Array();
var settings = new Array();
var itmCnt = 0;
var settingCnt = 0;

/*============================================================
FUNCTION:   getFile( )
PARAMETERS: N/A
RETURNS:    String - path to settings file
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
Verifies that the settings file exists, if not it creates it
in the AppData folder for the gadget. Starts off with basic
supported types.
==============================================================*/
function getFile()
{
    // get a File System Object reference
    var fso = getFSO();
    if (fso == null ) return "";
    strSettings = corePath();
    var strPath = System.Environment.getEnvironmentVariable("USERPROFILE") 
    // now, if the file does not exist, create it and fill it with
    // default data - as specified below...
    strSettings+="\\settings.dat";
    if (fso.fileExists(strSettings)==false)
    {
        //
        // FILE FORMAT:
        // -------------
        // <<GROUPING NAME>>
        // <<file extensions, seperated by semi-colons, terminating in a semi-colon>>
        // <<folder path>>
        //
        try {
            var fil = fso.CreateTextFile(strSettings);
            fil.WriteLine("Document Files");
            fil.WriteLine("doc;xls;ppt;docx;docm;xlsx;xlsm;pptx;pptm;vso;vsd;mpp;pub;xsn;txt;rtf;");
            fil.WriteLine(strPath + "\\Documents");
            fil.WriteLine("Picture Files");
            fil.WriteLine("jpg;jpeg;jpe;gif;tiff;tif;png;bmp;rle;dib;wmf;wmz;emf;emz;cgm;pict;pic;");
            fil.WriteLine(strPath + "\\Pictures");
            fil.WriteLine("Music Files");
            fil.WriteLine("wma;mp3;acc;aiff;wav;ra;mid;");
            fil.WriteLine(strPath + "\\Music");
            fil.WriteLine("Video Files");
            fil.WriteLine("wmv;avi;mpeg;mpg;vob;");
            fil.WriteLine(strPath + "\\Videos");
            fil.WriteLine("Internet Favorites");
            fil.WriteLine("url;");
            fil.WriteLine(strPath + "\\Favorites");
            fil.WriteLine("Downloaded Files");
            fil.WriteLine("exe;zip;cab;");
            fil.WriteLine(strPath + "\\Downloads");
            fil.Close();
        } catch (err) { throwError("Creating default settings file. " + err.description); }
    }
    
    return strSettings;
}

/*============================================================
FUNCTION:   corePath( )
PARAMETERS: N/A
RETURNS:    String - path to core settings folder
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
Creates the settings folder and returns its path
==============================================================*/
function corePath()
{
    var retVal = new String();
    // get a File System Object reference
    var fso = getFSO();
    if (fso == null ) return "";
    // connect to the AppData folder
    var retVal = System.Environment.getEnvironmentVariable("APPDATA") 
    retVal += "\\" + NAMESPACE + "\\" + SIDEBAR;
    // verify that each folder exists - one step at a time
    if (fso.folderExists(retVal)==false)
        fso.CreateFolder(retVal);
    retVal+="\\"+APP_NAME_INSTALL;
    if (fso.folderExists(retVal)==false)
        fso.CreateFolder(retVal);
    // return the result
    return retVal;
}

/*============================================================
FUNCTION:   coreReadAll( )
PARAMETERS: N/A
RETURNS:    true - success
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
Reads all of the settings file information into memory and 
places th data in the following arrays:
- sections[]
- extensions[]
- paths[]
==============================================================*/
function coreReadAll()
{
    itmCnt = 0; // reset!
    var fil = coreOpenSettings(1);
    try{
        // read in all the contents
        while(fil.AtEndOfStream==false)
        {
            sections[itmCnt] = fil.ReadLine();
            extensions[itmCnt] = fil.ReadLine();
            paths[itmCnt] = fil.ReadLine();
            itmCnt++;
        }
        fil.Close();
    } catch (err) { 
        throwError("Reading settings file. " + err.description); 
        return false
    }

    // success
    return true;
}

/*============================================================
FUNCTION:   coreOpenSettings( )
PARAMETERS: N/A
RETURNS:    File (FSO.File) file reference
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
Opens the core settings file in the mode desired:
1 = READ
2 = WRITE
8 = APPEND
It returns a reference to the opened file (FSO.File)
==============================================================*/
function coreOpenSettings(mode)
{
    var fso = getFSO();
    if ( fso == null ) return null;
    try {
        var fil = fso.OpenTextFile(getFile(),mode); 
    } catch  (err) {
        throwError("Opening settings file. " + err.description); 
        return null;
    }
    
    return fil;
}

/*============================================================
FUNCTION:   getFSO( )
PARAMETERS: N/A
RETURNS:    FileSystemObject reference
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
Returns a File System Object reference.
==============================================================*/
function getFSO()
{
    try {
        var fso = new ActiveXObject("Scripting.FileSystemObject");
    } catch (err) { 
        throwError("Initializing FSO. " + err.description); 
        return null;
    }
    
    return fso;
}

/*============================================================
FUNCTION:   writeNewExtension( string, string )
PARAMETERS: s (string) the area/section name for the ext type
            v (string) the extension to add
RETURNS:    bool (true if failed)
CREATED BY: David E. Craig
CREATED ON: 04/25/2007
DESCRIPTION:
Opens the setting sfile, locates the section (s) for the 
extension (v) being added and then add the extnesion to the
extensions list in the file.
==============================================================*/
function writeNewExtension(s, v)
{
    // read all the settings into memory
    if(!coreReadAll()) return false;
    // open the settings file for writing
    // get a reference to a FSO.File
    
    var fil = coreOpenSettings(2);
    if (fil != null)
    {
        try {
            for(i=0;i<itmCnt;i++)
            {
                fil.WriteLine(sections[i]);
                if(sections[i]==s)
                    fil.WriteLine(extensions[i] + v + ";");
                else
                    fil.WriteLine(extensions[i]);
                fil.WriteLine(paths[i]);
            }
            fil.Close();
           
        } catch (err) { 
            throwError("Updating the settings file. " + err.description);
            return false;
        }
    }
    else
    {
        return false;
    } 
    
    // success
    return true;
}

/*============================================================
FUNCTION:   writeNewType( string, string , string )
PARAMETERS: s (string) the area/section name for the ext type
            v (string) the extension to add
            p (string) the pth to the new location
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/25/2007
DESCRIPTION:
Opens the setting file, adds the new section and appends the
extension type to it.
==============================================================*/
function writeNewType(s, v, p)
{
    var fil = coreOpenSettings(8);
    if (fil==null) return false
    try {
        fil.WriteLine(s);
        fil.WriteLine(v + ";");
        fil.WriteLine(p);
        fil.Close();
    } catch (err) { 
        throwError("Updating the settings file. " + err.description); 
        return false;
    }
    
    // success
    return true;
}

/*============================================================
FUNCTION:   updateType( string , string )
PARAMETERS: s (string) the area/section name for the ext type
            p (atring) the new path
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Opens the setting file, updates the path for the section/file 
location in the settings file.
==============================================================*/
function updateType(s, p)
{
    if(coreReadAll()==false) return false;
    
    var fil = coreOpenSettings(2);
    if (fil==null) return false;
    
    // now write the file back...
    try {
        for(i=0;i<itmCnt;i++)
        {

            // write the data to the file
            fil.WriteLine(sections[i]);
            fil.WriteLine(extensions[i]);        
            if(sections[i] != s)
            {
                fil.WriteLine(paths[i]);
            }
            else
            {
                fil.WriteLine(p);
            }
        }
        fil.Close();   
        
    } catch (err) { 
        throwError("Updating the settings file. " + err.description); 
        return false;
    } 
    
    // success
    return true;
}

/*============================================================
FUNCTION:   removeType( string )
PARAMETERS: s (string) the area/section name for the ext type
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Opens the setting file, deletes the section/file location 
from the settings file.
==============================================================*/
function removeType(s)
{
    if(coreReadAll()==false) return false;
    
    var fil = coreOpenSettings(2);
    if( fil==null) return false;
    
    try {
        for(i=0;i<itmCnt;i++)
        {
            if(sections[i] != s)
            {
                // wriute th data to the file
                fil.WriteLine(sections[i]);
                fil.WriteLine(extensions[i]);
                fil.WriteLine(paths[i]);
            }
        }
        fil.Close(); 
           
    } catch (err) { 
        throwError("Updating the settings file. " + err.description); 
        return false;
    }
    
    // success
    return true;
}

/*============================================================
FUNCTION:   removeExtension( string, string )
PARAMETERS: s (string) the area/section name for the ext type
            x (string) the extension to remove
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/26/2007
DESCRIPTION:
Opens the setting file, deletes the extension from the
specified group.
==============================================================*/
function removeExtension(s, x)
{
    if (coreReadAll()==false) return false;
    
    var fil = coreOpenSettings(2);
    if (fil==null) return false;

    try {
        for(i=0;i<itmCnt;i++)
        {
            // parse the list of extensions...
            var arrExts = extensions[i].split(";");
            var extList="";
            for(j=0;j<arrExts.length;j++)
            {
                if(arrExts[j]!=x && arrExts[j]!="")
                    extList+=arrExts[j] + ";";
            }
            // wriute th data to the file
            fil.WriteLine(sections[i]);
            fil.WriteLine(extList);
            fil.WriteLine(paths[i]);
        }
        fil.Close();
    } catch (err) { throwError("Updating settings file. " + err.description); }    
}

/*============================================================
FUNCTION:   getFocus ( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/25/2007
DESCRIPTION:
Workaround to the refresh problem that occurs when changing 
the page in the settings file.
==============================================================*/
function getFocus() 
{
    self.focus();
}

/*============================================================
FUNCTION:   loadpage ( string )
PARAMETERS: p (string) new page URL
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/25/2007
DESCRIPTION:
Used by the hyerlinks at the top of SETTINGS1.HTML and 
SETTINGS2.HTML to change the page in the settings form.
==============================================================*/
function loadpage(p)
{
    location.replace(p);
}

/*============================================================
FUNCTION:   changeButton ( string , string )
PARAMETERS: n (string) id of img element
            s (string) path to an image
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Changee the image elements src to the specified string
==============================================================*/
function changeButton(o, p)
{
    if(o.disabled=="")
    {
        o.src=p;
    }
}

/*============================================================
FUNCTION:   initEvents ( object )
PARAMETERS: o (object) a document element
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Loop through the IMG elements in the document and all those
that are using the IMG-BUTTON class, add events to them so
that the following events make them dynamic buttons:
- onmouseover
- onmouseout
- onmousedown
- onmouseup
==============================================================*/
function initEvents(o)
{
    try{
        versionSpan.innerText=VERSION;
    } catch (ex) 
    { //do nothing 
    }
    
    // get all th image elemets
    var imgs=o.getElementsByTagName("img");
    
    // loop though the images
    try {
        for(i=0;i<imgs.length;i++)
        {
            // if they are from the specified class
            if(imgs[i].className=="img-button")
            {
                // build the image paths...
                var a = imgs[i].alt;
                
                var std = "../images/" + a + ".png";
                var hvr = "../images/" + a + "-h.png";
                var dwn = "../images/" + a + "-p.png";
                
                // apply the events
                imgs[i].onmouseover= new Function("changeButton(this,'" + hvr + "')");
                imgs[i].onmouseout= new Function("changeButton(this,'" + std + "')");
                imgs[i].onmousedown= new Function("changeButton(this,'" + dwn + "')");
                imgs[i].onmouseup= new Function("changeButton(this,'" + hvr + "')");
            }
        }
    } catch (err) { throwError("Initializing button animations. " + err.description); }
}

/*============================================================
FUNCTION:   changeTab ( object , string )
PARAMETERS: o (object) a TD tag
            s (string) a style name
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Changes the class of a TD object. These are animation events
to add highlights and effects to buttons, tabs and other 
controls.
==============================================================*/
function changeTab(o,c)
{
    if(o.className="tab-disabled" || o.className=="tab-hover")
    {
        o.className=c;
    }
}

/*============================================================
FUNCTION:   disableButton ( object )
PARAMETERS: o (object) an image (button)
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Disabled the image control - button.
==============================================================*/
function disableButton(o)
{
    o.disabled = "disabled";
    o.src = "../images/" + o.alt + "-d.png";
}

/*============================================================
FUNCTION:   enableButton ( object )
PARAMETERS: o (object) an image (button)
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Enabled the image control - button.
==============================================================*/
function enableButton(o)
{
    o.disabled = "";
    o.src = "../images/" + o.alt + ".png";
}

/*============================================================
FUNCTION:   throwError ( s )
PARAMETERS: s (string) - error message
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Closes active flyouts, then sets timef for error flyout.
==============================================================*/
function throwError(s)
{
    // set a timeout first before we show it
    System.Gadget.Settings.writeString("errorInfo",s);
    System.Gadget.Flyout.file="../html/fo_error.html";
    window.setTimeout("showError()",300);
}

/*============================================================
FUNCTION:   showError ( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/27/2007
DESCRIPTION:
Displays an error in a flyout.
==============================================================*/
function showError()
{
    try {
        if(System.Gadget.Flyout.show!=true)
        {
            System.Gadget.Flyout.show = true;
        }
    } catch (err) {  
        // nothing
    }
}

/*============================================================
FUNCTION:   showMessaage ( s )
PARAMETERS: s (string) - message to display
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/01/2007
DESCRIPTION:
Displays a message (s) on given forms that have the 
message span element
==============================================================*/
function showMessage(s)
{
    messageExt.innerText=s;
    messageFolder.innerText=s;
    window.setTimeout("messageExt.innerText=''",4000);
    window.setTimeout("messageFolder.innerText=''",4000);
}

/*============================================================
FUNCTION:   getSetting ( string )
PARAMETERS: s (string) - setting to get
RETURNS:    string - the value
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Get the specific user setting...
==============================================================*/
function getSetting(s)
{
    var path = corePath() + "\\" + s;
    var retVal="";
    
    var fso=getFSO();
    if(fso.FileExists(path))
    {
        var fil=fso.OpenTextFile(path);
        retVal=fil.ReadLine();
        fil.Close();
    }
    
    return retVal;
}

/*============================================================
FUNCTION:   saveSetting ( string )
PARAMETERS: s (string) - the setting name
            v (string) - the setting value
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Saves the specific user setting...
==============================================================*/
function saveSetting(s, v)
{
    var path = corePath() + "\\" + s;
    var fso = getFSO();
    
    if(fso.FileExists(path))
    {
        fso.DeleteFile(path);
    }
    
    var fil = fso.CreateTextFile(path);
    fil.WriteLine(v);
    fil.close();
}

/*============================================================
FUNCTION:   isValidFolder ( string )
PARAMETERS: path (string) - the path to test
RETURNS:    true/false
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
True if the path is valid and false if it is not
==============================================================*/
function isValidFolder(path)
{
    try{
        var fso = getFSO();
        return fso.FolderExists(path);
    } catch (err) { 
        throwError("Could not validate the path: " + err.description);
        return false;
    }
}