////////////////////////////////////////////////////////////////////////////////
//
//  THIS CODE IS NOT APPROVED FOR USE IN/ON ANY OTHER UI ELEMENT OR PRODUCT COMPONENT.
//  Copyright (c) 2007 David E. Craig.  All rights reserved.
//
////////////////////////////////////////////////////////////////////////////////

/*
DESCRIPTION
===========
MAIN_EVENTS.JS is the core event file for all code
specific to the MAIN.HTML form.

This is the core starting point for the GADGET. The main functions
here are the setupGadget where the settings file is loaded into 
memory and the fileDragDropped function which handles the main
prupose of the GADGET.

NOTE: External dependencies are added in the parent HTML
*/

// GLOBALS
var exts;
var paths;
var names;
var folderColor = new String();
var folderSize = new Number();
var folderStyle = new String();
var undockSize = new Number();
var bStopUpdateStatus = false;
var bStatusFlash = false;
var moveFlags = 28; //maybe a future option here...
var fPromptOff = false;
var fNoCheckForUpdate = false;
var fPauseLoop = false;

// PARAMETERS, RESULTS AND SHARED VARS
var mainEventDetect_moveCancel = false;
var mainEventDetect_bulkCancel = false;
var mainProcess_bulkMove = false;
var mainResult_bulkPath = new String();
var mainResult_newPath = new String();
var mainParam_fileName = new String();
var mainParam_typeName = new String();
var mainParam_folderPath = new String();
var mainParam_extension = new String();

// for DRAG-DROP
var dragDropFileItems;
var dragDropFileExts;
var dragDropFolders;
var dragDropItemCnt=0;
var dragOrigCnt=0;
var dragDropFolderCnt=0;

// UI STUFF
System.Gadget.settingsUI="../html/settings.html";
System.Gadget.onSettingsClosed = settingsClosed;
System.Gadget.onDock = updateGadget;
System.Gadget.onUndock = updateGadget;

// for folder watch stuff
var lastFileCnt = 0;
var folderSpec = new String();

/*============================================================
FUNCTION:   setupGadget( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
Reads the settings file into memory into the two global arrays
- exts[1000]
- paths[1000]
==============================================================*/
function setupGadget()
{   
    detectDPI();
    
    folderStyle = getSetting("folderStyle");
    folderColor = getSetting("folderColor");
    folderSize = getSetting("folderSize");
    undockSize = getSetting("undockSize");
    
    // now, start by updating the gadget size/look, etc
    updateGadget();
    
    // initialize...
    exts = new Array();
    paths = new Array();
    names = new Array();
    
    var num = 0;
    var fil = coreOpenSettings(1);
    if( fil != null )
    {
        while(fil.AtEndOfStream==false)
        {
            try {
                // load the data
                var strName = fil.ReadLine();
                var strTypes = fil.ReadLine();
                var strPath = fil.ReadLine();
               
                // parse the file extensions
                var x = strTypes.split(";");
                for(i=0;i<x.length;i++)
                {
                    if(x[i].length > 0)
                    {
                        // add each extension to the array
                        exts[num] = x[i]; // exts is global
                        // match to the same index the path for that
                        // extension in the paths array...
                        paths[num] = strPath; // paths is global
                        names[num] = strName;
                        num++;
                    }
                }
            } catch (err) { 
                // we failed reading the settings file, so we need to delete
                // it then rebuild it...
                fil.Close();
                var strPath = getFile();
                var fso = getFSO();
                fso.DeleteFile(strPath, true);
                // throw the error
                throwError("Unable to read the settings file: " + err.description + ". It is being recreated."); 
                // start over...
                window.setTimeout("setupGadget()",100);
                return;
            }
        }
        fil.Close(); 
    }
    
    // initialize...
    init();
    if(fNoCheckForUpdate==false)
        checkForUpdateLoop();
    else
        fNoCheckForUpdate = false;
    
    // look for files in the special folder
    if(getSetting("folderWatch")=="true")
        startFolderWatchLoop();
}

/*============================================================
FUNCTION:   startFolderWatchLoop( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 09/28/2007
DESCRIPTION:
Starts the loop that looks for the "The Magic Folder" folder
in the users profile.
==============================================================*/
function startFolderWatchLoop()
{
    folderSpec = System.Environment.getEnvironmentVariable("USERPROFILE") + "\\The Magic Folder";
    var fso = getFSO();
    if (fso.FolderExists(folderSpec)==false)
        fso.CreateFolder(folderSpec);
    window.setTimeout("folderWatchLoop()",1000);
}

/*============================================================
FUNCTION:   folderWatchLoop( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 09/28/2007
DESCRIPTION:
Loop that looks for files being added to the "The Magic Folder"
folder that is located in the users profile.
==============================================================*/
function folderWatchLoop()
{
    if(fPauseLoop)
        return; // turn off the loop
        
    var fso = getFSO();
    var fol = fso.GetFolder(folderSpec);
    if(fol.Files.Count>0)
    {
        dragDropFileItems = new Array();
        dragDropFileExts = new Array();
        // catalog the files...
        catalogOnlyFiles(folderSpec)
        fPauseLoop = true;
        processDraggedItems();
    }
    
    if(getSetting("folderWatch")=="true")
        window.setTimeout("folderWatchLoop()",1000);
}

/*============================================================
FUNCTION:   settingsClosed( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/22/2007
DESCRIPTION:
Sets the flag to not prompt for update after settings is 
closed, because this could technically be very annoying...
==============================================================*/
function settingsClosed()
{
    fPromptOff = true;
    fNoCheckForUpdate = true; // do not reset the timer...
    setupGadget();
}

/*============================================================
FUNCTION:   detectDPI( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/20/2007
DESCRIPTION:
Checks the DPI settings on the system and then changes to the 
proper stylesheet.
==============================================================*/
function detectDPI()
{
    var path = System.Gadget.path + "\\css\\";
    var dpi = new Number(dpiTest.offsetWidth);
    var fso = getFSO();
    if(dpi>96) // hi-res fonts
    {
        fso.GetFile(path + "styles-120dpi.css").Copy(path + "styles.css",true);
    }
    else
    {
        fso.GetFile(path + "styles-96dpi.css").Copy(path + "styles.css",true);
    }
}

/*============================================================
FUNCTION:   updateGadget( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Runs when the gadgetis docked or undocked to change the
appearance of the gadget.
==============================================================*/
function updateGadget()
{
    if(folderColor==null || folderColor.length==0)
        folderColor="blue";
    
    if(folderStyle==null || folderStyle.length==0)
        if(folderColor=="blue")
            folderStyle="magic";
        else
            folderStyle="default";
	    
    if((undockSize==2 && !System.Gadget.docked) || 
       (folderSize==2 && System.Gadget.docked))
    {
         //  SMALL
        with (document.body.style)
        {
            width="72px";
            height="72px";
            margin="0px";
        }
        with (bg.style)
        {
            width="60px";
            height="60px";
            margin="0px";
        }
        bg.src = "../images/bg-small-" + folderColor + "-" + folderStyle  + ".png";
    }
    else if ((undockSize==0 && !System.Gadget.docked) || 
            (folderSize==0 && System.Gadget.docked))
    {
        // LARGE
        with (document.body.style)
        {
            width="130px";
            height="130px";
            margin="0px";
        }
        with (bg.style)
        {
            width="120px";
            height="120px";
            margin="0px";
        }
        bg.src = "../images/bg-large-" + folderColor + "-" + folderStyle  + ".png";
    }
    else
    {
         //  MEDIUM
        with (document.body.style)
        {
            width="100px";
            height="100px";
            margin="0px";
        }
        with (bg.style)
        {
            width="83px";
            height="83px";
            margin="0px";
        }
        bg.src = "../images/bg-small-" + folderColor + "-" + folderStyle  + ".png";        
    }
}

/*============================================================
FUNCTION:   init( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Runs after Setup to verify that the first run prompt has
happened for the user...useful information in there.
==============================================================*/
function init()
{
    if(getSetting(FIRST_RUN)!="true" && System.Gadget.Flyout.show==false)
    {
        System.Gadget.Flyout.file="../html/first_run.html";
        System.Gadget.Flyout.onHide=firstRun;
        System.Gadget.Flyout.show = true;    
    }
}

/*============================================================
FUNCTION:   firstRun( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
After the firstrun prompt, verify the user clicked ok.
==============================================================*/
function firstRun()
{
    if(System.Gadget.Settings.readString(FIRST_RUN)=="yes")
    {
        saveSetting(FIRST_RUN,"true");
    } 
}

/*============================================================
FUNCTION:   clickGadget( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
DESCRIPTION:
The gadget was clicked so we want to hide the flyout.
==============================================================*/
function clickGadget()
{
    System.Gadget.Flyout.show = false;
}

/*============================================================
FUNCTION:   fileDragDropped( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/24/2007
MODIFIED ON: 05/05/2007
DESCRIPTION:
Loads all the dropped files into an array for processing
It ignores all folders - no error.
Once completed, it calls the processDrop function with a
windowTimeout call.
==============================================================*/
function fileDragDropped() 
{        
    var oFile;
    // initialize
    dragDropFileItems = new Array();
    dragDropFileExts = new Array();
    dragDropFolders = new Array();
    dragDropItemCnt = 0;
    dragOrigCnt = 0;
    dragDropFolderCnt = 0;
   
    // load all the files into an array...
    try {
        for (var i=0; (oFile = System.Shell.itemFromFileDrop(event.dataTransfer, i)) != null; i++)
        {
            var theFile = System.Shell.itemFromPath(oFile.path);
            
            // verify it is NOT a folder first
            if(!theFile.isFolder || isZipFile(theFile))
            {
                updateStatus(1);
                // catalog the single file
                catalogFile(theFile);
            }
            else
            {
                // Process the folders
                updateStatus(1);
                // we need to catalog all the files in all of the subfolder
                if(getSetting("extUse")=="true")
                {
                    catalogFolder(theFile);    
                    // NOTE: The previous line is executed in
                    //       FSO.VBS. This is due to a limitation
                    //       when iterating subfolders...
                }
                else
                {
                    // extension are disabled - so in this case instead
                    // of gutting a file we will move the whole thing.
                    // So here we catalog the folder.
                    dragDropFolders[dragDropFolderCnt++] = oFile.path;
                }
            }
        }
    } catch (err) { 
        updateStatus(0); 
        throwError("Drag/Drop Operation. " + err.description); 
    }
    
    // If here...all the file data from the items
    // dragged onto the gadget are in memory.
    // Set the windowTimeout can call the handler
    // for the items...
    if(dragDropItemCnt>0 || dragDropFolderCnt>0)
    {
        dragOrigCnt = dragDropItemCnt;
        window.setTimeout("processDraggedItems()",100);
    }
    else
    {
        // turn off any notifications...
        updateStatus(0); 
    }
}

/*============================================================
FUNCTION:   getFileExtension( object )
PARAMETERS: oFile (object) - the file
RETURNS:    string - the file extension
CREATED BY: David E. Craig
CREATED ON: 06/12/2007
DESCRIPTION:
Returns the file extension for the specified file object
==============================================================*/
function getFileExtension(oFile)
{
    var fso = getFSO();
    var filItem = fso.GetFile(oFile.path);
    var start = instrrev(filItem.Path,".");
    var len = filItem.Path.length - start;
    var filExt = new String(filItem.Path.substr(start,len));
    return filExt;
}

/*============================================================
FUNCTION:   catalogFile( string )
PARAMETERS: s (string) - name of the dropped file
RETURNS:    true/false
CREATED BY: David E. Craig
CREATED ON: 05/24/2007
DESCRIPTION:
Returns tru is the file extension is either CAB or ZIP
==============================================================*/
function isZipFile(o)
{
    try{
        var s = getFileExtension(o);
        return s.toUpperCase()=="ZIP" || s.toUpperCase()=="CAB";
    } catch (err) { 
        // return false because it is an error
        return false;
     }
}


/*============================================================
FUNCTION:   catalogFile( object )
PARAMETERS: oFile (object) - reference to the dropped file
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/16/2007
DESCRIPTION:
Catalogs the file passed in as paramater within the 
dragDropFileItems() array...
==============================================================*/
function catalogFile(oFile)
{
    // now extract the extension
    var filExt = getFileExtension(oFile);
    // if the file does not have an extension the following will
    // be true - so the extension is nixed
    if(filExt==oFile.name)
        filExt="";
    
    // load the settings into the proper arrays...
    dragDropFileItems[dragDropItemCnt]=oFile;
    dragDropFileExts[dragDropItemCnt]=filExt;

    dragDropItemCnt++;    
}

/*============================================================
FUNCTION:   processDraggedItems( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Called by the DragDrop operation this function will process the
list of files that were found.
==============================================================*/
function processDraggedItems()
{   
    try {
        // process as long as the flyout is NOT shown
        if(!System.Gadget.Flyout.show)
        {  
            // next, does user want process by extensions...
            if(getSetting("extUse")=="true" && dragDropItemCnt>0)
            {
                // reset and clean up
                resetParams();
               
                // process the files in reverse...
                dragDropItemCnt--;
                // is this a registered file extension?
                if(findItemInArray(exts,dragDropFileExts[dragDropItemCnt])==-1)                
                {
                    // UNKNOWN FILE TYPE - show the unknown extension panel...
                    mainEventDetect_moveCancel = false;
                    mainParam_filePath = dragDropFileItems[dragDropItemCnt].path;
                    mainParam_fileName = dragDropFileItems[dragDropItemCnt].name;
                    mainParam_extension = dragDropFileExts[dragDropItemCnt];
                    System.Gadget.Flyout.file="../html/fo_unknown.html";
                    System.Gadget.Flyout.onHide=moveUnknown;
                    System.Gadget.Flyout.show = true;
                    return;
                }
                else
                {
                    // cleanup first
                    resetParams();
                    
                    // KNOWN FILE TYPE - MOVE IT
                    var num = findItemInArray(exts,dragDropFileExts[dragDropItemCnt]);
                    if(isValidFolder(paths[num]))
                    {
                        var oFolder = System.Shell.itemFromPath(paths[num]).SHFolder;
                        oFolder.moveHere(dragDropFileItems[dragDropItemCnt], moveFlags);
                        // write to settings...
                        mainParam_fileName = dragDropFileItems[dragDropItemCnt].name;
                        mainParam_typeName = names[num];
                        mainParam_folderPath = paths[num];
                    }
                    else
                    {
                        throwError("Invalid or missing folder: \n\n" + paths[num]);
                        updateStatus(0);
                        return;
                    }
                }   
            }
            else if(getSetting("extUse")!="true" && (dragDropItemCnt>0 || dragDropFolderCnt>0) )
            {
                // clean up first
                resetParams();
         
                // extensions are not enabled...(BULK MODE)
                mainProcess_bulkMove=true;
                System.Gadget.Flyout.file="../html/fo_jump.html";
                System.Gadget.Flyout.onHide=moveBulk;
                System.Gadget.Flyout.show = true;
                return;
            }
        
            // is the process completed?
            if(dragDropItemCnt>0)
            {
                window.setTimeout("processDraggedItems()",100);
            }
            else
            {
                if(fPauseLoop==true)
                {
                    fPauseLoop = false;
                    // we will not show the prompt here
                    window.setTimeout("folderWatchLoop()",1000);
                }
                else
                    showPrompt();
            }
        }
    } catch (ex) {
        throwError("General error processing items.");
        updateStatus(0);
        return;
    }
}

/*============================================================
FUNCTION:   resetParams( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/16/2007
DESCRIPTION:
Resets the parameters just before a file operation to make sure
there are not any conflicts...
==============================================================*/
function resetParams()
{
    mainEventDetect_moveCancel = false;
    mainEventDetect_bulkCancel = false;
    mainProcess_bulkMove = false;
    mainResult_bulkPath = "";
    mainResult_newPath = "";
    mainParam_fileName = "";
    mainParam_typeName = "";
    mainParam_folderPath = "";
    mainParam_extension = "";
}

/*============================================================
FUNCTION:   moveBulk( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
When the user has extension based moving turned off the
Gadget will perform bulk moving. This means every file
will be moved to the same selected folder. If a bulk
move was determined in processDraggedItems, then this fn
is called when the user has completed their folder selection.
==============================================================*/
function moveBulk()
{
    System.Gadget.Flyout.onHide = function(){};

    if(mainEventDetect_bulkCancel==false)
    {
        // get the folder
        if(isValidFolder(mainResult_bulkPath))
        {
            // move files
            for(i=0;i<dragDropItemCnt;i++)
            {    
                // move it...
                moveFile(mainResult_bulkPath,dragDropFileItems[i].path);
                // write to settings...
                mainParam_fileName=dragDropFileItems[i].name;
                mainParam_folderPath=mainResult_bulkPath;
            }
            
            // move fodlers
            for(i=0;i<dragDropFolderCnt;i++)
            {
                // move it
                moveFolder(dragDropFolders[i],mainResult_bulkPath);
                mainParam_fileName=getFolderNameFromPath(dragDropFolders[i]);
                mainParam_folderPath=mainResult_bulkPath;
            }
            
            showPrompt();
        }
        else
        {
            throwError("Invalid or missing folder: \n\n" + mainResult_bulkPath);
        }
    }

    //clean-up
    mainEventDetect_bulkCancel = false;
    mainParam_bulkMove = false;
    mainParam_bulkPath = "";
    updateStatus(0);
    dragDropItemCnt=0;
    dragDropFolderCnt=0;
}

/*============================================================
FUNCTION:   moveUnknown( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
When the user has extension based moving turned on, if a
file extension is determined to be unknown the user is
prompted with the option to register the extension to a
folder. When the user has selected that folder, this fn
is what is called.
==============================================================*/
function moveUnknown()
{
    System.Gadget.Flyout.onHide = function(){};

    if(!mainEventDetect_moveCancel)
    {
        // first, process any items that need to be moved....
        if(isValidFolder(mainResult_newPath))
        {
            moveFile(mainResult_newPath,mainParam_filePath);
            // we have to set this flag here, because if we do not, when we go into
            // setup gadget, the update routine will get fired off and we will see
            // the update window - if needed - just before the confirmation screen.
            fNoCheckForUpdate = true;
            // reload the settings
            setupGadget();
            //reset the window timeout...
            window.setTimeout("processDraggedItems()",100);
        }
        else
        {
            throwError("Invalid or missing folder: \n\n" + mainResult_newPath);
        }
    }
    else
        mainPanel.innerText="";
    
    // clean-up...
    mainEventDetect_moveCancel = false;
    mainResult_newPath = "";
    updateStatus(0);
}

/*============================================================
FUNCTION:   moveFile( string, object )
PARAMETERS: path (string) - the path to the folder where
                            the file is to be moved.
            file (object) - the FILE object from the drag
                            operation that is to be moved
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Core move function that is called any time a file is needed
to be moved.
==============================================================*/
function moveFile(path, file)
{
    try {
        if(file.length>0 && path.length>0)
        {
            var oFile = System.Shell.itemFromPath(file);
            var oFolder = System.Shell.itemFromPath(path).SHFolder;
            oFolder.moveHere(oFile, moveFlags);
        }
    } catch (err) { throwError("Move file, Drag/Drop Operation. " + err.description); }
}

/*============================================================
FUNCTION:   moveFile( string, string )
PARAMETERS: src (string)  - the source folder
            dest (string) - the destination folder
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 06/01/2007
DESCRIPTION:
Core move function that is called any time a folder is needed
to be moved.
==============================================================*/
function moveFolder(src, dest)
{
    try {
        var fso = getFSO();
        dest += '\\' + getFolderNameFromPath(src);
        fso.MoveFolder(src,dest); 
    } catch (err) { throwError("Move folder, Drag/Drop Operation. " + err.description); }
}

/*============================================================
FUNCTION:   getFolderNameFromPath( string )
PARAMETERS: folPath (string)  - the folder
RETURNS:    string - name of the folder minus path
CREATED BY: David E. Craig
CREATED ON: 06/01/2007
DESCRIPTION:
Returns only the name of the folder form the given path
==============================================================*/
function getFolderNameFromPath(folPath)
{
    var startPos = folPath.lastIndexOf('\\') + 1;
    return folPath.substring(startPos,folPath.length);
}

/*============================================================
FUNCTION:   showPrompt( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Determines which prompt to show the user:
1) If only one file was moved a more detailed message is shown
2) If many were moved a simple status is shown
==============================================================*/
function showPrompt()
{
    // if the user does not want to be annoyed by the confirmation
    // prompt, they turned on this setting in the Settings form, so
    // skip out of here...
    if (getSetting("turnOffConfirm")=="true") 
    {
        updateStatus(0); // turn off notify
        return;
    }
    
    // now show the flyouts.
    if((dragOrigCnt + dragDropFolderCnt)==1)
    {
        // may sure the slyout is hidden
        System.Gadget.Flyout.show = false;
        // set the timeout...
        window.setTimeout("return showFlyout('../html/fo_confirm.html')",1000);
    }
    else
    {
        // may sure the slyout is hidden
        System.Gadget.Flyout.show = false;
        // set the timeout...
        window.setTimeout("return showFlyout('../html/fo_confirm2.html')",1000);
    }
    updateStatus(0); // turn off notify
}

/*============================================================
FUNCTION:   updateStatus( int )
PARAMETERS: b (int) - number to determine the
                      busy notification icon....
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/05/2007
DESCRIPTION:
Loads a busy notification icon in the folder display to let the
user know a move operation is in progres...
==============================================================*/
function updateStatus(b)
{
    switch(b)
    {
        case 0:
            mainPanel.innerHTML="";
            bStopUpdateStatus = true;
            break;
        case 1:
            window.setTimeout("statusLoop()",500);
            break;
    }
    self.focus();                       
}

/*============================================================
FUNCTION:   statusLoop( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/16/2007
DESCRIPTION:
Turns on/off the blinking status light...
==============================================================*/
function statusLoop()
{
    if(bStopUpdateStatus)
    {
        window.setTimeout("resetStatus()",1000);
        return;
    }

    if(bStatusFlash)
    {
        mainPanel.innerHTML="<img src='../images/light-red.gif' />";
        bStatusFlash = false;
    }
    else
    {
        mainPanel.innerHTML="<img src='../images/light-yellow.gif' />";
        bStatusFlash = true;
    }
    
    window.setTimeout("statusLoop()",500);
}

/*============================================================
FUNCTION:   resetStatus( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/16/2007
DESCRIPTION:
Turns off the blinking status light...
==============================================================*/
function resetStatus()
{
    bStopUpdateStatus = false;
    mainPanel.innerHTML="<img src='../images/light-green.gif' />";
    window.setTimeout("mainPanel.innerHTML='';",3000);
}

/*============================================================
FUNCTION:   showFlyOut( string )
PARAMETERS: s (string) - path to flyout HTML to show
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/25/2007
DESCRIPTION:
Called by the dopFile operation after a 1 second timeout.
Displays the flyout (s) for the user...
==============================================================*/
function showFlyout(s)
{   
    System.Gadget.Flyout.file=s;
    System.Gadget.Flyout.show = true;
}

/*============================================================
FUNCTION:   mainPanel_onclick ( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 04/25/2007
DESCRIPTION:
The user clicked on the gadget. Show the JUMP flyout...
==============================================================*/
function mainPanel_onclick()
{
    System.Gadget.Flyout.file="../html/fo_jump.html";
    System.Gadget.Flyout.show = true;
}

/*============================================================
FUNCTION:   checkForUpdateLoop ( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/22/2007
DESCRIPTION:
Loops every 8 hours looking for an update
==============================================================*/
function checkForUpdateLoop()
{
    // if user does not want to be reminded, tturn it off
    if(getSetting("stopRemind")=="true") return;
    // check for update
    checkForUpdate();
    // loop once every 8-hours               
    window.setTimeout("checkForUpdateLoop();",28800000);
}

/*============================================================
FUNCTION:   checkForUpdate ( )
PARAMETERS: N/A
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/22/2007
DESCRIPTION:
Checks to see if there is an update available.
==============================================================*/
function checkForUpdate()
{
    try {
        var url = UPDATE_URL;
        var pars = 'ver=' + VERSION;
        var myAjax = new Ajax.Request(
		                                url, 
   		                            {
		                                method: 'post', 
		                                parameters: pars, 
		                                onComplete: parseResponse
 		                            });
 	} catch (ex) { /* DO NOTHING */ }
}

/*============================================================
FUNCTION:   checkForUpdate ( string )
PARAMETERS: originalRequest (string) - response from AJAX
RETURNS:    N/A
CREATED BY: David E. Craig
CREATED ON: 05/22/2007
DESCRIPTION:
Checks to see if there is an update available.
==============================================================*/
function parseResponse(originalRequest)
{
    var sVer = new String(originalRequest.responseText);
    if(sVer=="UPDATE" && System.Gadget.Flyout.show==false && fPromptOff==false)
        showFlyout('../html/fo_update.html');
    else
        fPromptOff = false;  
}